@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.14;
+our $VERSION = 0.15;
 
 # Get XML.
 has xml => (
@@ -81,7 +81,7 @@ For more information about Málaga Map, click L<here|https://es.wikipedia.org/wi
 =item C<get_lines()>
 
  Get lines in metro map.
- Returns reference to array with Map::Tube::Line objects.
+ Returns reference to unsorted array with Map::Tube::Line objects.
 
 =item C<get_node_by_id($station_id)>
 
@@ -195,6 +195,29 @@ For more information about Málaga Map, click L<here|https://es.wikipedia.org/wi
 
 =end html
 
+=head1 EXAMPLE4
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::Malaga;
+
+ # Object.
+ my $obj = Map::Tube::Malaga->new;
+
+ # Get lines.
+ my $lines_ar = $obj->get_lines;
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } sort @{$lines_ar};
+
+ # Output:
+ # Línea 1
+ # Línea 2
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -242,6 +265,6 @@ I dedicate this module to my visit in Málaga.
 
 =head1 VERSION
 
-0.14
+0.15
 
 =cut
